==> haskell-hls-code-range-plugin-2.1.0.0-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-code-range-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-code-range-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-code-range-plugin-2.1.0.0-3DxsbZjYAMlKMxvyp4TkYW
key:                  hls-code-range-plugin-2.1.0.0-3DxsbZjYAMlKMxvyp4TkYW
license:              Apache-2.0
maintainer:           kokobd
author:               kokobd
synopsis:
    HLS Plugin to support smart selection range and Folding range

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  f6bcdd2e779e742116242c6ca60ece21
exposed:              True
exposed-modules:      Ide.Plugin.CodeRange Ide.Plugin.CodeRange.Rules
hidden-modules:       Ide.Plugin.CodeRange.ASTPreProcess
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-code-range-plugin
hs-libraries:         HShls-code-range-plugin-2.1.0.0-3DxsbZjYAMlKMxvyp4TkYW
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 extra-1.7.16-KxrHBQWVwMp2M62XitBte8
    ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    hls-plugin-api-2.1.0.0-2mMBQBjk997A47exxFPkZd
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    lsp-2.1.0.0-GxokUjVxBLy4j05JlhgdFg mtl-2.2.2
    semigroupoids-6.0.1-6I5b3GpOwhwAglmgd4w9RR text-2.0.2
    transformers-0.5.6.2 vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57

haddock-interfaces:
    /usr/share/doc/haskell-hls-code-range-plugin/html/hls-code-range-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-code-range-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-code-range-plugin-2.1.0.0-94-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-code-range-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-code-range-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-code-range-plugin-2.1.0.0-2ivabopq2h2H4IQbJtofdM
key:                  hls-code-range-plugin-2.1.0.0-2ivabopq2h2H4IQbJtofdM
license:              Apache-2.0
maintainer:           kokobd
author:               kokobd
synopsis:
    HLS Plugin to support smart selection range and Folding range

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  9320d8203cefddc354a549c4239a27e1
exposed:              True
exposed-modules:      Ide.Plugin.CodeRange Ide.Plugin.CodeRange.Rules
hidden-modules:       Ide.Plugin.CodeRange.ASTPreProcess
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-code-range-plugin
hs-libraries:         HShls-code-range-plugin-2.1.0.0-2ivabopq2h2H4IQbJtofdM
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 extra-1.7.16-CyTEZvSfBxsKCwY9ZtJE7E
    ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    hls-plugin-api-2.1.0.0-EfBvd6pBF3is65S9wzuFu
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    lsp-2.1.0.0-4wEItkatDyfAFCzTPH6SAN mtl-2.2.2
    semigroupoids-6.0.1-Bxz0f1JNfGSLvZg0Ig0I9J text-2.0.2
    transformers-0.5.6.2 vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:
    /usr/share/doc/haskell-hls-code-range-plugin/html/hls-code-range-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-code-range-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
